
/*                       SCL1.LIB Screen Functions Demo

	To run this demo inside QuickC environment:

		Copy SCL1.H into your INCLUDE subdirectory.
		Load SCL1 Quick Library.
		Turn Screen Swapping On (QC's Debug Menu).
		Compile it (memory output option and debug option on if you
					want to step through).


		To Load SCL1 Quick Library:

			qc /l scl1

	File SCL1.QLB must be located in the path specified in the LIB
	environment variable directory or in your default drive/path

	*/


#include <scl1.h>

char Color1=BROWN_BLACK+HIGHLIGHT,Color2=WHITE_BLUE;
char WinBuffer[126];

main()
{
int i,L1,C1,L2,C2;
char WinFlag;

/*Set Video mode to Alphanumeric mode */

InitVideo();

/* Do we have Mono or Color monitor?
   in case of Mono change colors to B&W */

if(Video()==MONO)
	Color1=WHITE_BLACK,Color2=BLACK_WHITE;

/* Save cursor size and turn it off. GetCurSize returns cursor size
   but also saves its size in variable CURSOR_SIZE */

GetCurSize();
CursorOff();

/* Clear screen with Color1
	Parameters for Cls: Color, Top Right Corner Line, Top Right Corner Column
				Bottom Left Corner Line, Bottom Left Corner Column */

Cls(Color1,0,0,24,79);

/* Draw all types of boxes available
	Parameters for Box: Color, Box Type (0-11),Top Right Corner Line,
					Top Right Corner Column,Bottom Left Corner Line,
					Bottom Left Corner Column */

for(i=0,L1=0,C1=0,L2=24,C2=79;i<12;++i,++L1,++C1,--L2,--C2)
	Box(Color1,i,L1,C1,L2,C2);

/* Write a string directly to video buffer
	WriteScreen parameters: Color, Line, Column, pointer to string */

WriteScreen(Color2,L1,25," Press any Key to Continue...");

GetKey(); /* Wait for a key */

/* Use CLS_ALL to clear the whole screen */

Cls(Color1,CLS_ALL);

/* Draw a box that grows, makes sounds and has shadows
	GSSBox parameters: first six parameters are the same as Box
			add Grow Flag (1=grow), SoundFlag and Shadow Flag */

GSSBox(Color1,1,10,10,20,70,1,1,1);
WriteScreen(Color2,L1,25," Press any Key to Continue...");
GetKey();

/* Write a character X number of times

	WriteChar parameters: Color, Line, Column, Number of times, character */

WriteChar(Color1,0,0,2000,'@');

/* Clear and Save an area of the screen

	Window parameters: Color, Top Right Corner Line, Top Right Corner Column
					   Top Right Corner Column,Bottom Left Corner Line,
					   Bottom Left Corner Column,WindowFlag address,
					   Window Buffer

	Window Flag must be set to 0 if you want to save and clear area
			or to -2 if you only want to save area
	Window Buffer = ((BottomLine - TopLine)+1) * (((Right Column - Left Column)+1)*2)

			*/
WinFlag=0;
Window(Color2,10,30,12,50,&WinFlag,WinBuffer);

/* Write to saved area using WriteScreen, note the use of \n */

WriteScreen(Color2,10,34,"AAAAAAAAAAAAA\nAAAAAAAAAAAAA\nPress any key");
GetKey();

/* Restore area */

Window(Color2,10,30,12,50,&WinFlag,WinBuffer);
WriteScreen(Color2,8,25,"Area restored, press any key...");
GetKey();

/* Use MessageOn to display a box/message on the screen
	Screen can be restored by calling MessageOff.
	Message can have up to 5 lines of up to 40 characters each
	Parameters:
			Color, and pointer to string */

MessageOn(Color2,"  You can draw a box and a message   \n and later, restore the screen very\neasily using MessageOn and MessageOff!\n\n           Press any key...");

/* Wait for any key */

GetKey();

/* Restore screen */

MessageOff();

/* Restore cursor size and exit */

SetCurSize(CURSOR_SIZE);

}
